==> haskell-neat-interpolation-0.5.1.4-167-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-FtOUjEeg3uZKUKNQdqfNCl
key:                  neat-interpolation-0.5.1.4-FtOUjEeg3uZKUKNQdqfNCl
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  67a7b8c2a7c2885d01b8c49cb93ed030
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-FtOUjEeg3uZKUKNQdqfNCl
depends:
    base-4.17.2.1 megaparsec-9.7.0-8vxoLKsvFvg2EeYv7J5Buq
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.5.1.4-188-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-7XPSlxvtItq5pBrn3Wiexy
key:                  neat-interpolation-0.5.1.4-7XPSlxvtItq5pBrn3Wiexy
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  4d9c2eee77e950c2935ac5348e96ac6c
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-7XPSlxvtItq5pBrn3Wiexy
depends:
    base-4.17.2.1 megaparsec-9.7.0-A5HZG6HxQB028mYZSYROei
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
